/*
 *   This file is part of Dianara
 *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#include "mischelpers.h"

MiscHelpers::MiscHelpers(QObject *parent) : QObject(parent)
{
    // Creating object not required
}


QString MiscHelpers::getCachedAvatarFilename(QString url)
{
    QString localFilename;
#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
    localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
#else
    localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
#endif
    localFilename.append("/avatars/");
    localFilename.append(url.trimmed().toUtf8().toBase64());

    QString fileExtension = url;
    fileExtension.remove(QRegExp(".*\\.")); // remove all but the extension

    localFilename.append(".");
    localFilename.append(fileExtension);

    return localFilename;
}







QString MiscHelpers::getCachedImageFilename(QString url)
{
    QString localFilename;
#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
    localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
#else
    localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
#endif
    localFilename.append("/images/");
    localFilename.append(url.trimmed().toUtf8().toBase64());


    return localFilename;
}




/*
 * Parse a string of HTML and replace the URL in each <img src=""> tag with
 * the corresponding locally cached filename.
 *
 * Return also the string list of the URL's to download
 *
 */
QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml)
{
    // if no <img tag is found, just return the original HTML
    if (!originalHtml.contains("<img"))
    {
        return QStringList(originalHtml);
    }

    qDebug() << "MiscHelpers::htmlWithReplacedImages(); HTML contains some <img> tags...";
    QString newHtml = originalHtml;

    QStringList imageList;
    QString imgSrc;

    QRegExp regExp("\\<img(.+)src=\"([^\"]+)\"\\s(.*)\\>");
    regExp.setMinimal(true);

    int matchedLength;
    int stringPos = 0;
    while (matchedLength != -1)
    {
        stringPos = regExp.indexIn(newHtml, stringPos);
        matchedLength = regExp.matchedLength();


        qDebug() << "regExp match = " << regExp.cap(0);
        qDebug() << "Groups:" << regExp.cap(1) << " // " << regExp.cap(2) << " // " << regExp.cap(3);
        qDebug() << "Matched length is:" << matchedLength;

        imgSrc = regExp.cap(2);
        if (!imgSrc.isEmpty()) // if not an empty string, add to the list, and replace HTML
        {
            imageList.append(imgSrc);

            newHtml.replace(stringPos,
                            matchedLength,
                            "<img src=\"" + getCachedImageFilename(imgSrc) +  "\" width=\"320\"/>");
        }

        stringPos += matchedLength; // FIXME: error control
    }

    imageList.insert(0, newHtml); // The modified HTML goes before the image list
    qDebug() << "Returned HTML and images:\n" << imageList;

    return imageList;
}


/*
 * Basic cleanup of HTML stuff
 *
 */
QString MiscHelpers::cleanHtml(QString originalHtml)
{
    QString cleanHtml = originalHtml;


    cleanHtml.replace("\n", " ");  // Remove line breaks, as that results in server error 500


    QRegExp headRE("<html><head>.*</head>");
    headRE.setMinimal(true);

    cleanHtml.remove(headRE);
    cleanHtml.remove("</body></html>");

    QRegExp bodyRE("<body style.*>");
    bodyRE.setMinimal(true);

    cleanHtml.remove(bodyRE);

    return cleanHtml;
}
